@@ -9,7 +9,7 @@ require "rubygems"
 require "highline/import"
 
 loop do
-  cmd = ask("Enter command:  ", %w{save load reset quit}) do |q|
+  cmd = ask("Enter command:  ", %w{save sample load reset quit}) do |q|
     q.readline = true
   end
   say("Executing \"#{cmd}\"...")
