@@ -44,6 +44,14 @@ class TestHighLine < Test::Unit::TestCase
     assert_equal(true, @terminal.agree("Yes or no?  ", :getc))
   end
   
+  def test_agree_with_block
+    @input << "\n\n"
+    @input.rewind
+
+    assert_equal(true, @terminal.agree("Yes or no?  ") { |q| q.default = "y" })
+    assert_equal(false, @terminal.agree("Yes or no?  ") { |q| q.default = "n" })
+  end
+  
   def test_ask
     name = "James Edward Gray II"
     @input << name << "\n"
@@ -404,7 +412,7 @@ class TestHighLine < Test::Unit::TestCase
   end
   
   def test_mode
-    assert(%w[Win32API termios stty].include?(HighLine::CHARACTER_MODE))
+    assert(%w[Win32API termios ncurses stty].include?(HighLine::CHARACTER_MODE))
   end
   
   class NameClass
@@ -662,14 +670,14 @@ class TestHighLine < Test::Unit::TestCase
     assert_equal(animal, answer)
 
     @input.truncate(@input.rewind)
-    @input << "6/16/76\n"
+    @input << "16th June 1976\n"
     @input.rewind
 
     answer = @terminal.ask("Enter your birthday.", Date)
     assert_instance_of(Date, answer)
     assert_equal(16, answer.day)
     assert_equal(6, answer.month)
-    assert_equal(76, answer.year)
+    assert_equal(1976, answer.year)
 
     @input.truncate(@input.rewind)
     pattern = "^yes|no$"
